#!/usr/env python

import argparse
import sys

from update_package.buildcommon import *


def check_label(label):
    """
    Validate update label
    """
    if not valid_label(label):
        sys.exit("%s: invalid label: %s" % (sys.argv[0], label))
    return label


def parse_args_or_exit(argv=None):
    """
    Parse command line options
    """
    parser = argparse.ArgumentParser(description="Create XML document")
    parser.add_argument("-l", "--label", type=check_label, required=True,
                        help="Update textual label")
    parser.add_argument("-p", "--driver_packages", required=True, nargs='+',
                        help="Driver packages")
    parser.add_argument("-o", "--output", required=True, help="Output XML file name")
    return parser.parse_args(argv)


def main(argv):
    """
    Generate a group file (XML document) suitable for driver driver updates
    """
    args = parse_args_or_exit(argv)
    driver_disk_group_file(args.output, args.label, args.driver_packages)


def _main():
    """
    Entry point for setuptools CLI wrapper
    """
    main(sys.argv[1:])


# Entry point when run directly
if __name__ == "__main__":
    _main()
