#!/usr/env python

import argparse
import sys

from update_package.buildcommon import *


def check_uuid(uuid):
    """
    Validate UUID
    """
    if not valid_uuid(uuid):
        sys.exit("%s: invalid UUID: %s" % (sys.argv[0], uuid))
    return uuid


def check_label(label):
    """
    Validate update label
    """
    if not valid_label(label):
        sys.exit("%s: invalid label: %s" % (sys.argv[0], label))
    return label


def check_uuid_label(uuid_label):
    """
    Validate uuid:label format
    """
    if not valid_uuid_label(uuid_label):
        sys.exit("%s: invalid uuid:label: %s" % (sys.argv[0], uuid_label))
    return uuid_label


def parse_args_or_exit(argv=None):
    """
    Parse command line options
    """
    parser = argparse.ArgumentParser(description="Create XML document")
    parser.add_argument("--uuid", type=check_uuid, required=True,
                        help="Update unique identifier")
    parser.add_argument("-l", "--label", type=check_label, required=True,
                        help="Update textual label")
    parser.add_argument("-v", "--version", required=True,
                        help="Update version")
    parser.add_argument("-d", "--description", required=True,
                        help="Update description")
    parser.add_argument("-o", "--output", metavar="XML", required=True,
                        help="Output XML document")
    parser.add_argument("--rolled-up-by", type=check_uuid_label,
                        metavar="UUID:Name-label",
                        help="Update that rolls this up")
    parser.add_argument("--follows", type=check_label,
                        metavar="LABEL", action="append",
                        help="Service Pack that precedes this hotfix")

    return parser.parse_args(argv)


def main(argv):
    """
    Generate an XML document suitable for rollups
    """
    args = parse_args_or_exit(argv)
    create_update_doc(args.output, args.uuid, args.label, args.version,
                      args.description, None, None, None, 0,
                      rolled_up_by=args.rolled_up_by, follows=args.follows)


def _main():
    """
    Entry point for setuptools CLI wrapper
    """
    main(sys.argv[1:])


# Entry point when run directly
if __name__ == "__main__":
    _main()
