#!/usr/bin/env python

import argparse
import os.path
import sys


def parse_args_or_exit(argv=None):
    """
    Parse command line options
    """
    parser = argparse.ArgumentParser(description="Print binary packages related to source packages")
    parser.add_argument("sourcepaths", metavar="FILELIST",
                        help="File containing source package filenames")
    parser.add_argument("src2binmap", metavar="MAP",
                        help="File containing source to binary package mapping")

    return parser.parse_args(argv)


def main(argv):
    """
    Print binary packages related to source packages
    """
    args = parse_args_or_exit(argv)

    # read the source packages into an array
    srcbases = []
    with open(args.sourcepaths) as fileh: 
        for line in fileh:
            srcbases.append(os.path.basename(line.strip()))

    # print the binary packages of source packages present
    with open(args.src2binmap) as fileh:
        for line in fileh:
            srcbase, binpkg = line.strip().split()
            if srcbase in srcbases:
                print binpkg


def _main():
    """
    Entry point for setuptools CLI wrapper
    """
    main(sys.argv[1:])


# Entry point when run directly
if __name__ == "__main__":
    _main()
