#############################################################################
#
# Generic Makefile rules for hotfix generation containing livepatches.
#
# This file should be included at the bottom of an update makefile using
#
#     include $(shell update-resource --livepatch-makefile)
#
# All mandatory variables for hotfix updates described in update.mk must be
# defined above that line.
#
# The following variables must also be defined:
#
#      LIVEPATCH_PACKAGES - the list of livepatch package names  to be
#                           contained in the hotfix
#############################################################################

include $(shell update-resource --makefile)

EXTRA_REPOS_FILE := $(WORK_DIR)/extra-repos
-include $(EXTRA_REPOS_FILE)

PREV_PRECHECK_SCRIPT := $(PRECHECK_SCRIPT)
PRECHECK_SCRIPT := $(WORK_DIR)/livepatch-precheck

ifeq ($(UPDATE_TYPE),hotfix)
PAYLOAD_PACKAGES += $(LIVEPATCH_PACKAGES)
endif

$(ISO): $(PRECHECK_SCRIPT)

$(PACKAGE_PATHS): $(EXTRA_REPOS_FILE)

.DELETE_ON_ERROR: $(EXTRA_REPOS_FILE)
$(EXTRA_REPOS_FILE): $(PACKAGES_LIST)
	@mkdir -p $(@D)
	@touch $@
	echo "$(LIVEPATCH_PACKAGES)" | grep --quiet 'kernel-\([[:alnum:]]*-\)\?livepatch_' && echo "UPDATE_REPOS += kernel-lp" >>$@ || :
	echo "$(LIVEPATCH_PACKAGES)" | grep --quiet 'xen-\([[:alnum:]]*-\)\?livepatch_' && echo "UPDATE_REPOS += xen-lp" >>$@ || :

.DELETE_ON_ERROR: $(PRECHECK_SCRIPT)
$(PRECHECK_SCRIPT): $(PACKAGE_PATHS)
	@rm -f $@
	[ -n "$(PREV_PRECHECK_SCRIPT)" ] && sed -e '$$ d' $(PREV_PRECHECK_SCRIPT) >$@ || :
	$(shell update-resource --generate-livepatch-precheck) $$(< $(PACKAGE_PATHS)) >>$@
