import sys
import subprocess
import re
import os.path

from update_package.common import *

components = [{'component': 'xen',
               'pkg': 'xen-hypervisor',
               'lp-pkg': 'xen-livepatch'},
              {'component': 'kernel',
               'pkg': 'kernel',
               'lp-pkg': 'kernel-livepatch'}]


def get_complete_version(rpm):
    # Get the version-release of the component for which rpm provides a
    # live patch such that the live patch is equivalent to that component
    # at version-release.
    out = subprocess.check_output(["rpm", "-qp", "--provides", rpm])
    for line in out.split("\n"):
        match = re.match("livepatch\(.*?([^-]+-[^-]+)\)$", line.strip())
        if match:
            return match.group(1)


def get_target_version(rpm):
    # Get the target version-release of the component for which rpm provides a
    # live patch; i.e. the version-release of the component which the livepatch
    # is applied onto.
    out = subprocess.check_output(["rpm", "-qp", "--provides", rpm])
    for line in out.split("\n"):
        match = re.match("livepatch-target\(.*?([^-]+-[^-]+)\)$", line.strip())
        if match:
            return match.group(1)


def get_livepatch_info(work_dir):
    livepatches = []
    # Find all the livepatch RPMs in this hotfix
    packages = glob.glob(os.path.join(work_dir, "root/Packages/*.rpm"))
    for comp in components:
        for rpm in packages:
            match = re.match("%s_.*([0-9]+)-([0-9]+)\.x86_64\.rpm$" %
                             comp['lp-pkg'], os.path.basename(rpm))
            if match:
                complete_version = get_complete_version(rpm)
                target_version = get_target_version(rpm)

                livepatches.append({
                    'component': comp['component'],
                    'complete-version': complete_version,
                    'target-version': target_version
                })
    return livepatches
